"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandNames = exports.rcOptionsTypes = exports.cliOptionsTypes = void 0;
exports.help = help;
exports.handler = handler;
const cli_utils_1 = require("@pnpm/cli-utils");
const common_cli_options_help_1 = require("@pnpm/common-cli-options-help");
const config_1 = require("@pnpm/config");
const store_connection_manager_1 = require("@pnpm/store-connection-manager");
const core_1 = require("@pnpm/core");
const render_help_1 = __importDefault(require("render-help"));
const install_1 = require("./install");
Object.defineProperty(exports, "cliOptionsTypes", { enumerable: true, get: function () { return install_1.cliOptionsTypes; } });
Object.defineProperty(exports, "rcOptionsTypes", { enumerable: true, get: function () { return install_1.rcOptionsTypes; } });
const recursive_1 = require("./recursive");
exports.commandNames = ['unlink', 'dislink'];
function help() {
    return (0, render_help_1.default)({
        aliases: ['dislink'],
        description: 'Removes the link created by `pnpm link` and reinstalls package if it is saved in `package.json`',
        descriptionLists: [
            {
                title: 'Options',
                list: [
                    {
                        description: 'Unlink in every package found in subdirectories \
or in every workspace package, when executed inside a workspace. \
For options that may be used with `-r`, see "pnpm help recursive"',
                        name: '--recursive',
                        shortAlias: '-r',
                    },
                    ...common_cli_options_help_1.UNIVERSAL_OPTIONS,
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('unlink'),
        usages: [
            'pnpm unlink (in package dir)',
            'pnpm unlink <pkg>...',
        ],
    });
}
async function handler(opts, params) {
    if (opts.recursive && (opts.allProjects != null) && (opts.selectedProjectsGraph != null) && opts.workspaceDir) {
        await (0, recursive_1.recursive)(opts.allProjects, params, {
            ...opts,
            allProjectsGraph: opts.allProjectsGraph,
            selectedProjectsGraph: opts.selectedProjectsGraph,
            workspaceDir: opts.workspaceDir,
        }, 'unlink');
        return;
    }
    const store = await (0, store_connection_manager_1.createOrConnectStoreController)(opts);
    const unlinkOpts = Object.assign(opts, {
        ...(0, config_1.getOptionsFromRootManifest)(opts.rootProjectManifestDir, opts.rootProjectManifest ?? {}),
        globalBin: opts.bin,
        storeController: store.ctrl,
        storeDir: store.dir,
    });
    if (!params || (params.length === 0)) {
        await (0, core_1.mutateModulesInSingleProject)({
            dependencyNames: params,
            manifest: await (0, cli_utils_1.readProjectManifestOnly)(opts.dir, opts),
            mutation: 'unlinkSome',
            rootDir: opts.dir,
        }, unlinkOpts);
        return;
    }
    await (0, core_1.mutateModulesInSingleProject)({
        manifest: await (0, cli_utils_1.readProjectManifestOnly)(opts.dir, opts),
        mutation: 'unlink',
        rootDir: opts.dir,
    }, unlinkOpts);
}
//# sourceMappingURL=unlink.js.map